﻿using MindFusion.Diagramming.Wpf;
using System.Diagnostics;
using System.Numerics;
using System.Windows;
using System.Windows.Media;

namespace MindfusionIssues
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private readonly Diagram diagram;

        public MainWindow()
        {
            InitializeComponent();

            diagram = Diagram;

            diagram.MiddleButtonActions = MouseButtonActions.Pan;
            diagram.Behavior = Behavior.Modify;

            // Place items in the grid
            Random random = new Random();

            Diagram.ZoomFactor = 100;

            var imageNode = new SvgNode()
            {
                Transparent = true,
                Bounds = new Rect()
            };
            imageNode.Image = ImageUtils.CreateImage(".\\images\\controller.png");

            diagram.Nodes.Add(imageNode);
            diagram.Nodes.First().Move(100, 100);
        }

        public static Matrix3x2 CreateTRSMatrix(Vector2 position, float rotation, Vector2 scale)
        {
            float cos = MathF.Cos(rotation);
            float sin = MathF.Sin(rotation);

            Debug.Assert(scale.X != 0 && scale.Y != 0, "Incorrect scale matrix.");

            return new Matrix3x2(
                cos * scale.X,
                sin * scale.X,
                -sin * scale.Y,
                cos * scale.Y,
                position.X,
                position.Y);
        }

        private void ReflectHorizontally(object sender, RoutedEventArgs e)
        {
            var matrixTransform = new MatrixTransform();
            var trs = CreateTRSMatrix(new Vector2(100, 100), rotation: 0, new Vector2(-1, 1));
            matrixTransform.Matrix = new Matrix(trs.M11, trs.M12, trs.M21, trs.M22, trs.M31, trs.M32);

            var imageNode = diagram.Nodes.First();

            imageNode.RenderTransform = matrixTransform;
        }

        private void ReflectVertically(object sender, RoutedEventArgs e)
        {
            var matrixTransform = new MatrixTransform();
            var trs = CreateTRSMatrix(new Vector2(100, 100), rotation: 0, new Vector2(1, -1));
            matrixTransform.Matrix = new Matrix(trs.M11, trs.M12, trs.M21, trs.M22, trs.M31, trs.M32);

            var imageNode = diagram.Nodes.First();

            imageNode.RenderTransform = matrixTransform;
        }
    }
}